pub(crate) struct RenderContext<'a, 'db> {
completion: &'a CompletionContext<'a, 'db>,
is_private_editable: bool,
import_to_add: Option<LocatedImport>,
doc_aliases: Vec<SmolStr>,
}Expand description
Interface for data and methods required for items rendering.
Fields
completion: &'a CompletionContext<'a, 'db>is_private_editable: boolimport_to_add: Option<LocatedImport>doc_aliases: Vec<SmolStr>Implementations
Sourceimpl<'a, 'db> RenderContext<'a, 'db>
impl<'a, 'db> RenderContext<'a, 'db>
pub(crate) fn new( completion: &'a CompletionContext<'a, 'db>, ) -> RenderContext<'a, 'db>
pub(crate) fn private_editable(self, private_editable: bool) -> Self
pub(crate) fn import_to_add(self, import_to_add: Option<LocatedImport>) -> Self
pub(crate) fn doc_aliases(self, doc_aliases: Vec<SmolStr>) -> Self
fn snippet_cap(&self) -> Option<SnippetCap>
fn db(&self) -> &'a RootDatabase
fn source_range(&self) -> TextRange
fn completion_relevance(&self) -> CompletionRelevance
fn is_immediately_after_macro_bang(&self) -> bool
Sourcefn is_deprecated(
&self,
def: impl HasAttrs,
def_as_assoc_item: Option<AssocItem>,
) -> bool
fn is_deprecated( &self, def: impl HasAttrs, def_as_assoc_item: Option<AssocItem>, ) -> bool
Whether def is deprecated.
This can happen for two reasons:
- the def is marked with
#[deprecated] - the def is an assoc item whose trait is deprecated
In order to be able to check for the latter, we’d ideally want to try_as_dyn<_, dyn AsAssocItem>(def)
(see try_as_dyn), but that function is currently unstable. Therefore, we employ a hack instead:
if def can be an assoc item, it should be passed to this method as follows:
ⓘ
self.is_deprecated(def, Some(def))otherwise, it should be passed as:
ⓘ
self.is_deprecated(def, None)Sourcefn is_variant_deprecated(&self, variant: EnumVariant) -> bool
fn is_variant_deprecated(&self, variant: EnumVariant) -> bool
Whether an enum variant should be rendered as deprecated.
A variant inherits deprecation from its parent enum, matching rustc’s
behavior where #[deprecated] on an enum applies to its variants.
fn docs(&self, def: impl HasDocs) -> Option<Documentation<'a>>